@@ -9,9 +9,7 @@ __ALL__ = ["AESCipher"]
 
 class AESCipher(object):
     def __init__(self, key: str_or_bytes) -> None:
-        if isinstance(key, str):
-            key = utf8e(key)
-        self.key = hashlib.sha256(key).digest()
+        self.key = hashlib.sha3_256(try_utf8e(key)).digest()
 
     def encrypt(self, raw: str_or_bytes) -> str:
         raw = _pad(raw)
